pub struct DefaultPark { /* fields omitted */ }Creates a new DefaultPark instance.
Formats the value using the given formatter. Read more
Unpark handle type for the Park implementation.
Get a new Unpark handle associated with this Park instance.
Block the current thread unless or until the token is available. Read more
Park the current thread for at most duration. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static